# Posty

Posty is just a basic command line URL shortener that uses the Tinyurl API.

---

## Installation
You can install it from PyPi with `pip install Posty` or locally with `pip install .`.

## Usage
You can run Posty by writing `posty` on the command line. It will copy the content of your clipboard, validate if it is a valid URL
with Regex, shorten it and copy it to the clipboard again.